@@ -2,11 +2,12 @@
 #'
 #' This function clears the memoised cache of all functions memoised by `nflreadr`.
 #'
+#' @rdname clear_cache
 #' @export
 #' @return A success message after clearing the cache.
 #' @examples
-#' .clear_cache()
-.clear_cache <- function(){
+#' clear_cache()
+clear_cache <- function(){
 
   functions <- list(
     raw_from_url,
@@ -17,5 +18,11 @@
 
   lapply(functions, memoise::forget)
 
-  message("nflreadr function cache cleared!")
+  cli::cli_alert_success("nflreadr function cache cleared!")
+
+  invisible(TRUE)
 }
+
+#' @rdname clear_cache
+#' @export
+.clear_cache <- clear_cache
