@@ -69,6 +69,9 @@ test_that("load_schedules", {
 
   expect_gt(nrow(schedules), 6000)
 
+  valid_roof_values <- c("closed", "dome", "outdoors", "open", "retractable", NA_character_)
+  expect_true(all(schedules$roof %in% valid_roof_values))
+
   expect_error(load_schedules("2020"))
 
   sched_2020 <- load_schedules(2020)
@@ -173,15 +176,11 @@ test_that("load_espn_qbr", {
   skip_if_offline("github.com")
 
   qbr_default <- load_espn_qbr()
-  qbr_nfl_weekly <- load_espn_qbr(league = "nfl", seasons = TRUE, summary_type = "weekly")
-  qbr_cfb_season <- load_espn_qbr(league = "college", seasons = 2019:2020)
+  qbr_weekly <- load_espn_qbr(seasons = TRUE, summary_type = "week")
 
   expect_s3_class(qbr_default, "nflverse_data")
-  expect_s3_class(qbr_nfl_weekly, "nflverse_data")
-  expect_s3_class(qbr_cfb_season, "nflverse_data")
-  # expect_gt(nrow(qbr_default), 30)
-  expect_gt(nrow(qbr_nfl_weekly), 7500)
-  expect_gt(nrow(qbr_cfb_season), 200)
+  expect_s3_class(qbr_weekly, "nflverse_data")
+  expect_gt(nrow(qbr_weekly), 7500)
 })
 
 test_that("load_trades", {
