@@ -17,13 +17,13 @@ test_that("cleaning team abbreviations", {
 
 test_that("cleaning player names", {
 
-  p <- c("Trubisky,      Mitch", "Atwell, Chatarius", "Elliott, Zeke", "Elijah Moore", "A.J. Green", "Odell Beckham Jr.   ")
+  p <- c("Trubisky,      Mitch", "Atwell, Chatarius", "Elliott, Zeke", "Elijah Moore", "A.J. Green", "Odell Beckham Jr.   ", "Audric Estimé")
 
   lower <- clean_player_names(p,lowercase = TRUE, use_name_database = TRUE, convert_lastfirst = TRUE)
 
   expect_equal(
     lower,
-    c("mitchell trubisky", "tutu atwell","ezekiel elliott", "elijah moore", "aj green", "odell beckham"))
+    c("mitchell trubisky", "tutu atwell","ezekiel elliott", "elijah moore", "aj green", "odell beckham", "audric estime"))
 
   otc <- c("Willie Gay, Jr.", "Jerry Rice, Jr.")
 
